@@ -4,6 +4,7 @@
 from .featureclassifier import FeatureClassifier
 from .deepregressor import DeepRegressor
 from .nbodyregressor import NbodyRegressor
+from .analyticalclassifier import AnalyticalClassifier
 from .version import __version__
 
-__all__ = ["FeatureClassifier", "DeepRegressor", "NbodyRegressor"]
+__all__ = ["FeatureClassifier", "DeepRegressor", "NbodyRegressor", "AnalyticalClassifier"]
